@@ -20,6 +20,8 @@ if subsystem == 'http' then
     require "resty.core.phase"
     require "resty.core.ndk"
     require "resty.core.socket"
+    require "resty.core.coroutine"
+    require "resty.core.param"
 end
 
 
