@@ -2,9 +2,12 @@ package t::TestCore::Stream;
 
 use Test::Nginx::Socket::Lua::Stream -Base;
 use Cwd qw(cwd);
+use Test::Nginx::Util 'is_tcp_port_used';
 
 $ENV{TEST_NGINX_HOTLOOP} ||= 10;
 
+sub get_unused_port ($);
+
 our $pwd = cwd();
 
 our $lua_package_path = './lib/?.lua;../lua-resty-lrucache/lib/?.lua;;';
@@ -37,6 +40,7 @@ our @EXPORT = qw(
     $lua_package_path
     $init_by_lua_block
     $StreamConfig
+    get_unused_port
 );
 
 add_block_preprocessor(sub {
@@ -47,4 +51,20 @@ add_block_preprocessor(sub {
     }
 });
 
+sub get_unused_port ($) {
+    my $port = shift;
+
+    my $i = 1000;
+    srand($$); # reset the random seed
+    while ($i-- > 0) {
+        my $rand_port = $port + int(rand(65535 - $port));
+        if (!is_tcp_port_used $rand_port) {
+            #warn "found unused port $rand_port, pid $$\n";
+            return $rand_port;
+        }
+    }
+
+    die "no unused port available";
+}
+
 1;
